@@ -86,11 +86,13 @@ char	*cp;
 	int	i;
 	char	buf[MAX_CMD_LEN];
 
-	if (current_not_defined()) {
+	i = cur_equation;
+	if (i < 0 || i >= n_equations || n_lhs[i] <= 0 || n_rhs[i] <= 0) {
+		error(_("No current equation."));
 		return false;
 	}
 	if (*cp == '\0') {
-		my_strlcpy(prompt_str, _("Enter variable: "), sizeof(prompt_str));
+		my_strlcpy(prompt_str, _("Enter variable or 0: "), sizeof(prompt_str));
 		if ((cp = get_string(buf, sizeof(buf))) == NULL) {
 			return false;
 		}
@@ -181,7 +183,11 @@ int	product_flag;	/* true for product, otherwise sum */
 		return false;
 	}
 	if (*cp) {
-		cp1 = cp;
+		if (*cp == '=') {
+			cp1 = skip_space(cp + 1);
+		} else {
+			cp1 = cp;
+		}
 	} else {
 		list_var(v, 0);
 		snprintf(prompt_str, sizeof(prompt_str), "%s = ", var_str);
@@ -285,18 +291,21 @@ int		en;		/* equation space number */
 	int	i, j, k;
 	int	level;
 	int	diff_sign;
-	int	found_se = true;
+	int	found_se;	/* found sub-expression flag */
 
-	for (level = 1; found_se; level++) {
+	if (!solved_equation(en)) {
+		return false;
+	}
+	for (level = 1, found_se = true; found_se; level++) {
 		for (i = 1, found_se = false; i < *np; i = j + 2) {
-			for (j = i; j < *np && equation[j].level > level; j += 2)
+			for (j = i; j < *np && equation[j].level >= level; j += 2)
 				;
 			if (j == i) {
 				continue;
 			}
 			found_se = true;
 			k = i - 1;
-			if ((j - k) >= OPT_MIN_SIZE && se_compare(&equation[k], j - k, rhs[en], n_rhs[en], &diff_sign)) {
+			if (se_compare(&equation[k], j - k, rhs[en], n_rhs[en], &diff_sign)) {
 				if (diff_sign) {
 					blt(&equation[i+2], &equation[j], (*np - j) * sizeof(token_type));
 					*np -= (j - (i + 2));
@@ -337,11 +346,11 @@ int		*np;
 	int	i, j, k, i1, i2, jj1, k1;
 	int	level, level1;
 	int	diff_sign;
-	int	found_se, found_se1;
+	int	found_se, found_se1;	/* found sub-expression flags */
 	long	v;
+	char	temp_buf[50];
 
-	found_se = true;
-	for (level = 1; found_se; level++) {
+	for (level = 1, found_se = true; found_se; level++) {
 		for (i = 1, found_se = false; i < *np; i = j + 2) {
 			for (j = i; j < *np && equation[j].level > level; j += 2)
 				;
@@ -367,11 +376,14 @@ int		*np;
 					k1 = i1 - 1;
 					if ((jj1 - k1) >= OPT_MIN_SIZE
 					    && se_compare(&equation[k], j - k, &equation[k1], jj1 - k1, &diff_sign)) {
-						if (last_temp_var > MAX_SUBSCRIPT) {
+						snprintf(temp_buf, sizeof(temp_buf), "temp%d", last_temp_var);
+						if (parse_var(&v, temp_buf) == NULL) {
+							return false;	/* can't create "temp" variable */
+						}
+						last_temp_var++;
+						if (last_temp_var < 0) {
 							last_temp_var = 0;
 						}
-						v = V_TEMP + (((long) last_temp_var) << VAR_SHIFT);
-						last_temp_var++;
 						i2 = next_espace();
 						lhs[i2][0].level = 1;
 						lhs[i2][0].kind = VARIABLE;
@@ -430,27 +442,44 @@ char	*cp;
 	int	i, j, k, i1;
 	int	start, stop;
 	int	rv = false;
-	int	flag;
+	int	start_en;
 
 	if (!get_range_eol(&cp, &start, &stop)) {
 		return false;
 	}
+	opt_en[0] = -1;
+	start_en = 0;
+	for (i = start; i <= stop; i++) {
+		simp_sub(i);
+	}
+	for (i = start; i <= stop; i++) {
+		for (j = start; j <= stop; j++) {
+			if (i != j) {
+				while (find_more(rhs[i], &n_rhs[i], j)) {
+					rv = true;
+				}
+			}
+		}
+	}
 	for (i = start; i <= stop; i++) {
 		if (n_lhs[i] == 0)
 			continue;
-		opt_en[0] = -1;
-		simp_sub(i);
-		flag = false;
+		for (j = 0; opt_en[j] >= 0; j++) {
+			simp_sub(opt_en[j]);
+			while (find_more(lhs[i], &n_lhs[i], opt_en[j]))
+				;
+			while (find_more(rhs[i], &n_rhs[i], opt_en[j]))
+				;
+		}
 		while (opt_es(lhs[i], &n_lhs[i])) {
-			flag = true;
+			rv = true;
 		}
 		while (opt_es(rhs[i], &n_rhs[i])) {
-			flag = true;
-		}
-		if (flag) {
 			rv = true;
-			for (i1 = 0; opt_en[i1] >= 0; i1++) {
-				for (j = 0; opt_en[j] >= 0; j++) {
+		}
+		if (rv) {
+			for (i1 = start_en; opt_en[i1] >= 0; i1++) {
+				for (j = start_en; opt_en[j] >= 0; j++) {
 					for (k = j + 1; opt_en[k] >= 0; k++) {
 						while (find_more(rhs[opt_en[k]], &n_rhs[opt_en[k]], opt_en[j]))
 							;
@@ -461,8 +490,8 @@ char	*cp;
 				while (opt_es(rhs[opt_en[i1]], &n_rhs[opt_en[i1]]))
 					;
 			}
-			for (j = 0; opt_en[j] >= 0; j++) {
-				list_sub(opt_en[j]);
+			for (; opt_en[start_en] >= 0; start_en++) {
+				list_sub(opt_en[start_en]);
 			}
 			list_sub(i);
 		}
@@ -969,9 +998,10 @@ char	*cp;
 	long		counter_max;
 	sign_array_type	sa_mark;
 	sign_array_type	sa_value;
-	int		iterations = 1;
-	int		n;
+	long		l, iterations = 1;
 	token_type	*source;
+	int		n;
+	int		diff_sign;
 
 	if (current_not_defined()) {
 		return false;
@@ -1035,17 +1065,22 @@ char	*cp;
 	if (it_v) {
 		list_var(it_v, 0);
 		snprintf(prompt_str, sizeof(prompt_str), _("Enter initial %s: "), var_str);
-		while (!get_expr(scratch, &n))
+		while (!get_expr(tes, &n_tes))
 			;
+		calc_simp(tes, &n_tes);
 		blt(tlhs, trhs, n_trhs * sizeof(token_type));
 		n_tlhs = n_trhs;
-		for (j = 0; j < iterations; j++) {
+		for (l = 0; l < iterations; l++) {
 			blt(trhs, tlhs, n_tlhs * sizeof(token_type));
 			n_trhs = n_tlhs;
-			subst_var_with_exp(trhs, &n_trhs, scratch, n, it_v);
+			subst_var_with_exp(trhs, &n_trhs, tes, n_tes, it_v);
 			calc_simp(trhs, &n_trhs);
-			blt(scratch, trhs, n_trhs * sizeof(token_type));
-			n = n_trhs;
+			if (se_compare(trhs, n_trhs, tes, n_tes, &diff_sign) && !diff_sign) {
+				printf(_("Convergence reached after %ld iterations.\n"), l + 1);
+				break;
+			}
+			blt(tes, trhs, n_trhs * sizeof(token_type));
+			n_tes = n_trhs;
 		}
 	} else {
 		simp_side(trhs, &n_trhs);
@@ -1551,7 +1586,7 @@ long	v;
 }
 
 /*
- * The flist command.
+ * The flist or display command.
  *
  * Displays equations in fraction format.
  */
@@ -1571,7 +1606,7 @@ char	*cp;
 	}
 	for (; i <= j; i++) {
 		if (n_lhs[i] > 0) {
-			group_sub(i);
+			make_fractions_and_group(i);
 			if (factor_flag || factor_int_flag) {
 				factor_int_sub(i);
 			}
@@ -1662,7 +1697,7 @@ char	*cp;
 			if (int_flag) {
 				uf_repeat_always(rhs[i], &n_rhs[i]);
 			}
-			group_sub(i);
+			make_fractions_and_group(i);
 			if (int_flag) {
 				if (!int_expr(rhs[i], n_rhs[i])) {
 					error(_("Not an integer equation."));
@@ -1995,7 +2030,7 @@ char	*cp;
 	if ((rv = setjmp(jmp_save)) != 0) {
 		clean_up();
 		if (rv == 14)
-			error(_("Expression too big."));
+			error(_("Expression too large."));
 		printf(_("Read operation aborted.\n"));
 		goto end_read;
 	}
