@@ -26,7 +26,7 @@ int
 roots_cmd(cp)
 char	*cp;
 {
-#define	MAX_ROOT	1000.0
+#define	MAX_ROOT	1000.0	/* put a limit here because more roots become more inaccurate */
 
 	complexs	c, c2, check;
 	double		d, k;
@@ -175,6 +175,9 @@ start_over:
 		modified = true;
 		goto start_over;
 	}
+	if (modified) {
+		debug_string(0, "Warning: complex number roots approximated, result may be inaccurate or incorrect.");
+	}
 	return modified;
 }
 
