@@ -60,8 +60,8 @@ long		v;
 
 	if (equation[loc].level < level) {
 /* First differentiate if it is a single variable or constant. */
-/* If it is the specified variable, change it to the constant "1.0", */
-/* otherwise change it to "0.0". */
+/* If it is the specified variable, change it to the constant 1, */
+/* otherwise change it to the constant 0. */
 		if (equation[loc].kind == VARIABLE
 		    && ((v == MATCH_ANY && (equation[loc].token.variable & VAR_MASK) > SIGN)
 		    || equation[loc].token.variable == v)) {
@@ -73,8 +73,7 @@ long		v;
 		}
 		return true;
 	}
-	op = 0;
-	for (oploc = endloc = loc + 1; endloc < *np && equation[endloc].level >= level; endloc += 2) {
+	for (op = 0, oploc = endloc = loc + 1; endloc < *np && equation[endloc].level >= level; endloc += 2) {
 		if (equation[endloc].level == level) {
 			switch (op) {
 			case 0:
@@ -120,9 +119,9 @@ long		v;
 		return true;
 	}
 /* Differentiate PLUS and MINUS operators. */
-/* Use rule: d(u+v) = d(u) + d(v), */
-/* where "d()" is the derivative function, */
-/* "u" and "v" are expressions. */
+/* Use addition rule: d(u+v) = d(u) + d(v), */
+/* where "d()" is the derivative function */
+/* and "u" and "v" are expressions. */
 	for (i = loc; i < *np && equation[i].level >= level;) {
 		if (equation[i].kind != OPERATOR) {
 			if (!d_recurse(equation, np, i, level + 1, v))
@@ -137,7 +136,7 @@ long		v;
 	return true;
 d_times:
 /* Differentiate TIMES operator. */
-/* Use rule: d(u*v) = u*d(v) + v*d(u). */
+/* Use product rule: d(u*v) = u*d(v) + v*d(u). */
 	if (*np + 1 + (endloc - loc) > n_tokens) {
 		error_huge();
 	}
@@ -153,7 +152,7 @@ d_times:
 	return(d_recurse(equation, np, loc, level + 2, v));
 d_divide:
 /* Differentiate DIVIDE operator. */
-/* Use rule: d(u/v) = (v*d(u) - u*d(v))/v^2. */
+/* Use quotient rule: d(u/v) = (v*d(u) - u*d(v))/v^2. */
 	if (*np + 3 + (endloc - loc) + (endloc - oploc) > n_tokens) {
 		error_huge();
 	}
@@ -186,7 +185,7 @@ d_divide:
 	return(d_recurse(equation, np, loc, level + 3, v));
 d_power:
 /* Differentiate POWER operator. */
-/* Since we don't have logarithms, just do what we can without them. */
+/* Since we don't have symbolic logarithms, do all we can without them. */
 	for (i = oploc; i < endloc; i++) {
 		if (equation[i].kind == VARIABLE
 		    && ((v == MATCH_ANY && (equation[i].token.variable & VAR_MASK) > SIGN)
@@ -309,6 +308,7 @@ char	*cp;
 		dest = lhs[i];
 		np = &n_lhs[i];
 	}
+/* parse the command line or prompt: */
 	if (*cp) {
 		if (is_all(cp)) {
 			cp = skip_param(cp);
@@ -353,6 +353,7 @@ char	*cp;
 #endif
 	blt(dest, source, *nps * sizeof(token_type));
 	n1 = *nps;
+/* do the actual differentiating and simplifying: */
 	for (l1 = 0; l1 < order; l1++) {
 		if (!differentiate(dest, &n1, v)) {
 			error(_("Differentiation failed."));
@@ -670,7 +671,6 @@ char	*cp;
 	long		v = 0;
 	token_type	solved_v, want;
 	char		*cp_start;
-	int		nl;
 	int		infinity_flag, found_den, complex_den, num, den;
 	int		level;
 
@@ -685,14 +685,14 @@ char	*cp;
 		n_lhs[cur_equation] = 1;
 		lhs[cur_equation][0].level = 1;
 		lhs[cur_equation][0].kind = VARIABLE;
-		lhs[cur_equation][0].token.variable = V_ANSWER;
+		parse_var(&lhs[cur_equation][0].token.variable, "answer");
 	}
 	if (!solved_equation(cur_equation)) {
 		error(_("The current equation is not solved for a variable."));
 		return false;
 	}
 	solved_v = lhs[cur_equation][0];
-	i = next_espace();
+/* parse the command line or prompt: */
 	if (*cp) {
 		cp = parse_var2(&v, cp);
 		if (cp == NULL) {
@@ -717,20 +717,29 @@ char	*cp;
 		if (!case_sensitive_flag) {
 			str_tolower(cp);
 		}
-		if ((cp = parse_section(lhs[i], &nl, cp)) == NULL || nl <= 0) {
+		if ((cp = parse_section(tes, &n_tes, cp)) == NULL || n_tes <= 0) {
 			return false;
 		}
 	} else {
 		list_var(v, 0);
 		snprintf(prompt_str, sizeof(prompt_str), _("as (%s) goes to: "), var_str);
-		if (!get_expr(lhs[i], &nl)) {
+		if (!get_expr(tes, &n_tes)) {
 			return false;
 		}
 	}
 	if (extra_garbage(cp))
 		return false;
-	simp_loop(lhs[i], &nl);
-	infinity_flag = exp_contains_infinity(lhs[i], nl);
+/* copy to a new equation space and work on the copy: */
+	i = next_espace();
+	blt(lhs[i], lhs[cur_equation], n_lhs[cur_equation] * sizeof(token_type));
+	n_lhs[i] = n_lhs[cur_equation];
+	blt(rhs[i], rhs[cur_equation], n_rhs[cur_equation] * sizeof(token_type));
+	n_rhs[i] = n_rhs[cur_equation];
+	cur_equation = i;
+/* see if the limit expression contains infinity: */
+	simp_loop(tes, &n_tes);
+	infinity_flag = exp_contains_infinity(tes, n_tes);
+/* fully simplify the current equation and group denominators together: */
 	simpa_side(rhs[cur_equation], &n_rhs[cur_equation], false);
 	group_proc(rhs[cur_equation], &n_rhs[cur_equation]);
 	found_den = false;
@@ -745,6 +754,7 @@ char	*cp;
 			for (k = j + 2;; k += 2) {
 				if (rhs[cur_equation][k-1].kind == VARIABLE
 				    && rhs[cur_equation][k-1].token.variable == v) {
+/* the limit variable was found in a denominator */
 					den = true;
 					found_den = true;
 				}
@@ -754,6 +764,7 @@ char	*cp;
 				switch (rhs[cur_equation][k].token.operatr) {
 				case DIVIDE:
 				case MODULUS:
+/* a denominator contains a fraction */
 					complex_den = true;
 					break;
 				}
@@ -761,6 +772,7 @@ char	*cp;
 			for (k = j - 1; k >= 0 && rhs[cur_equation][k].level >= level; k--) {
 				if (rhs[cur_equation][k].kind == VARIABLE
 				    && rhs[cur_equation][k].token.variable == v) {
+/* the limit variable was found in a numerator */
 					num = true;
 				}
 			}
@@ -772,15 +784,15 @@ char	*cp;
 	}
 	if (!found_den || (infinity_flag && !complex_den)) {
 /* in this case, just substitute the limit variable with the limit expression and simplify: */
-		subst_var_with_exp(rhs[cur_equation], &n_rhs[cur_equation], lhs[i], nl, v);
+		subst_var_with_exp(rhs[cur_equation], &n_rhs[cur_equation], tes, n_tes, v);
 		simpa_side(rhs[cur_equation], &n_rhs[cur_equation], false);
 		return return_result(cur_equation);
 	}
 	if (infinity_flag) {
 /* To take the limit to infinity, */
 /* replace infinity with zero and replace the limit variable with its reciprocal: */
-		nl = 1;
-		lhs[i][0] = zero_token;
+		n_tes = 1;
+		tes[0] = zero_token;
 		tlhs[0] = one_token;
 		tlhs[1].level = 1;
 		tlhs[1].kind = OPERATOR;
@@ -800,8 +812,8 @@ char	*cp;
 		return false;
 	}
 /* replace the limit variable (LHS) with the limit expression: */
-	blt(lhs[cur_equation], lhs[i], nl * sizeof(token_type));
-	n_lhs[cur_equation] = nl;
+	blt(lhs[cur_equation], tes, n_tes * sizeof(token_type));
+	n_lhs[cur_equation] = n_tes;
 /* symbolically simplify the RHS: */
 	symb_flag = true;
 	simpa_side(rhs[cur_equation], &n_rhs[cur_equation], false);
