@@ -8,17 +8,19 @@ extern int		n_tokens;
 extern int		n_equations;
 extern int		cur_equation;
 
-extern int		n_lhs[N_EQUATIONS];
-extern int		n_rhs[N_EQUATIONS];
-
 extern token_type	*lhs[N_EQUATIONS];
 extern token_type	*rhs[N_EQUATIONS];
 
-extern int		n_tlhs;
-extern int		n_trhs;
+extern int		n_lhs[N_EQUATIONS];
+extern int		n_rhs[N_EQUATIONS];
 
 extern token_type	*tlhs;
 extern token_type	*trhs;
+extern token_type	*tes;
+
+extern int		n_tlhs;
+extern int		n_trhs;
+extern int		n_tes;
 
 extern token_type	*scratch;
 
