@@ -53,7 +53,7 @@ static com_type com_list[] = {
 {	"limit",	NULL,			limit_cmd,	"variable expression",					"Take the limit of the current expression as variable goes to expression." },
 {	"list",		NULL,			list_cmd,	"[\"export\" or \"maxima\"] [equation-number-range]",	"Display stored expressions in single line format." },
 #if	!LIBRARY
-{	"nintegrate",	NULL,			nintegrate_cmd,	"[\"trapezoidal\"] variable [partitions]",		"Approximate the definite integral using Simpson's rule."},
+{	"nintegrate",	NULL,			nintegrate_cmd,	"[\"trapezoid\"] variable [partitions]",		"Approximate the definite integral using Simpson's rule."},
 {	"optimize",	NULL,			optimize_cmd,	"[equation-number-range]",				"Split up an equation into smaller multiple equations." },
 #endif
 #if	!LIBRARY
@@ -175,7 +175,7 @@ char	*cp;
 			n_rhs[n] = n_lhs[n];
 			lhs[n][0].level = 1;
 			lhs[n][0].kind = VARIABLE;
-			lhs[n][0].token.variable = V_ANSWER;
+			parse_var(&lhs[n][0].token.variable, "answer");
 			n_lhs[n] = 1;
 			i = cur_equation;
 			cur_equation = n;
@@ -382,6 +382,27 @@ char	*cp;	/* pointer to variable name string */
 
 #define P(A)	fprintf(gfp, "%s\n", A)
 
+/*
+ * Output command info and usage.
+ *
+ * Return the number of lines output.
+ */
+int
+display_command(i)
+int	i;	/* command index */
+{
+	int	rows = 3;
+
+	fprintf(gfp, "%s - %s\n", com_list[i].name, com_list[i].info);
+	fprintf(gfp, "Usage: %s %s\n", com_list[i].name, com_list[i].usage);
+	if (com_list[i].secondary_name) {
+		fprintf(gfp, "Alternate name for this command: %s\n", com_list[i].secondary_name);
+		rows++;
+	}
+	fprintf(gfp, "\n");
+	return rows;
+}
+
 /*
  * The help command.
  */
@@ -403,8 +424,7 @@ char	*cp;
 		for (i = 0; i < ARR_CNT(com_list); i++) {
 			if (strncasecmp(cp, com_list[i].name, cp1 - cp) == 0
 			    || (com_list[i].secondary_name && strncasecmp(cp, com_list[i].secondary_name, cp1 - cp) == 0)) {
-				fprintf(gfp, "%s - %s\n", com_list[i].name, com_list[i].info);
-				fprintf(gfp, "Usage: %s %s\n\n", com_list[i].name, com_list[i].usage);
+				display_command(i);
 				flag = true;
 			}
 		}
@@ -423,10 +443,11 @@ char	*cp;
 			P("    Area = b*h/2");
 			P("Rectangle of length \"l\" and width \"w\":");
 			P("    Area = l*w                    Perimeter = 2*l + 2*w");
-			P("Trapezoid of height \"h\" and parallel sides \"a\" and \"b\":");
-			P("    Area = h*(a + b)/2");
+			P("Trapezoid of parallel sides \"a\" and \"b\", and \"d\" distance between them:");
+			P("    Area = d*(a + b)/2");
 			P("Circle of radius \"r\":");
 			P("    Area = pi*r^2                 Perimeter = 2*pi*r");
+			P("    Area = Perimeter*r/2");
 			P("Rectangular solid of length \"l\", width \"w\", and height \"h\":");
 			P("    Volume = l*w*h                Surface area = 2*l*w + 2*l*h + 2*w*h");
 			P("Sphere of radius \"r\":");
@@ -449,29 +470,27 @@ char	*cp;
 			P("    * multiply        / divide          % modulus");
 			P("    + add             - subtract\n");
 			P("Operators in the same precedence level are evaluated left to right.\n");
-			P("Variables consist of any combination of letters, digits, underscores (_),");
-			P("and backslashes (\\).  Predefined constants and variables:\n");
+			P("Variables consist of any combination of letters, digits, and underscores (_).");
+			P("Constants always start with a digit (0..9) or a period.");
+			P("Predefined constants and variables follow:\n");
 			P("    e# - the universal constant e (2.7182818284...).");
 			P("    pi - the universal constant pi (3.1415926535...).");
 			P("    i# - imaginary number (square root of -1).");
-			P("    sign, sign1, sign2, sign3, ... - may be +1 or -1.");
+			P("    sign, sign1, sign2, sign3, ... - may only be +1 or -1.");
 			P("    integer - may be any integer.");
 			P("    inf - infinity constant.\n");
 			P("Absolute value notation \"|x|\" and \"+/-\" are understood.");
 			return true;
 		}
 		if (is_all(cp)) {
-			for (i = 0, row = 1;; i++, row += 3) {
-				if (gfp == stdout && screen_rows && row >= (screen_rows - 4)) {
+			for (i = 0, row = 1; i < ARR_CNT(com_list); i++) {
+				row += display_command(i);
+				if (gfp == stdout && screen_rows && row >= (screen_rows - 5)) {
 					row = 1;
 					if (!pause_cmd(""))
 						return false;
 					printf("\n");
 				}
-				if (i >= ARR_CNT(com_list))
-					break;
-				fprintf(gfp, "%s - %s\n", com_list[i].name, com_list[i].info);
-				fprintf(gfp, "Usage: %s %s\n\n", com_list[i].name, com_list[i].usage);
 			}
 			P("End of command list.");
 			return true;
