@@ -12,8 +12,6 @@ static int	integrate_sub();
 static int	laplace_sub();
 static int	inv_laplace_sub();
 
-static double	integrate_order;	/* global order of integration */
-
 /*
  * Make variable "v" always raised to a power,
  * unless it is on the right side of a power operator.
@@ -233,12 +231,11 @@ char	*cp;
 {
 	int		i, j;
 	long		v = 0;
-	double		d1;
 	token_type	*source, *dest;
 	int		n1, n2, *nps, *np;
 	int		def_flag;
+	double		d1, integrate_order = 1.0;
 
-	integrate_order = 1.0;
 	if (current_not_defined()) {
 		return false;
 	}
@@ -644,7 +641,7 @@ char	*cp;
 		error_huge();
 	}
 	if (trap_flag) {
-		debug_string(0, _("Approximating the definite integral using the trapezoidal method..."));
+		debug_string(0, _("Approximating the definite integral using the trapezoid method..."));
 	} else {
 		debug_string(0, _("Approximating the definite integral using Simpson's rule..."));
 	}
