@@ -60,7 +60,7 @@ matho_process(char *input, char **outputp)
 	if ((i = setjmp(jmp_save)) != 0) {
 		clean_up();	/* Mathomatic processing was interrupted, so do a clean up. */
 		if (i == 14) {
-			error(_("Expression too big."));
+			error(_("Expression too large."));
 		}
 		*outputp = error_str;
 		free(input);
@@ -100,7 +100,7 @@ matho_parse(char *input, char **outputp)
 	if ((i = setjmp(jmp_save)) != 0) {
 		clean_up();	/* Mathomatic processing was interrupted, so do a clean up. */
 		if (i == 14) {
-			error(_("Expression too big."));
+			error(_("Expression too large."));
 		}
 		*outputp = error_str;
 		free(input);
