@@ -128,7 +128,7 @@ int	n;	/* equation space number */
 		return false;
 	if (display2d) {
 		/* display in fraction format */
-		group_sub(n);
+		make_fractions_and_group(n);
 		if (factor_int_flag) {
 			factor_int_sub(n);
 		}
@@ -253,15 +253,6 @@ int	lang_code;	/* language code */
 	case MATCH_ANY:
 		cp = "all";
 		break;
-	case V_ANSWER:
-		cp = "answer";
-		break;
-	case V_TEMP:
-		cp = "temp";
-		break;
-	case V_INTEGER:
-		cp = "integer";
-		break;
 	default:
 		j = (v & VAR_MASK) - VAR_OFFSET;
 		if (j >= 0) {
@@ -459,6 +450,8 @@ int		n;		/* length of expression */
 char		*string;	/* buffer or NULL pointer */
 int		export_flag;
 {
+#define	APPEND(str)	{ if (string) { strcpy(&string[len], str); } len += strlen(str); }
+
 	int	i, j, k, i1;
 	int	min1;
 	int	cur_level;
@@ -475,14 +468,10 @@ int		export_flag;
 		for (i1 = 1; i1 <= k; i1++) {
 			if (j > 0) {
 				cur_level--;
-				if (string)
-					strcat(string, ")");
-				len++;
+				APPEND(")");
 			} else {
 				cur_level++;
-				if (string)
-					strcat(string, "(");
-				len++;
+				APPEND("(");
 			}
 		}
 		switch (equation[i].kind) {
@@ -492,23 +481,20 @@ int		export_flag;
 			}
 			if (high_prec || export_flag) {
 				if (equation[i].token.constant < 0.0) {
-					len += snprintf(buf, sizeof(buf), "(%.20g)", equation[i].token.constant);
+					snprintf(buf, sizeof(buf), "(%.20g)", equation[i].token.constant);
 				} else {
-					len += snprintf(buf, sizeof(buf), "%.20g", equation[i].token.constant);
+					snprintf(buf, sizeof(buf), "%.20g", equation[i].token.constant);
 				}
 			} else if (finance_option) {
-				len += snprintf(buf, sizeof(buf), "%.2f", equation[i].token.constant);
+				snprintf(buf, sizeof(buf), "%.2f", equation[i].token.constant);
 			} else {
-				len += snprintf(buf, sizeof(buf), "%.*g", precision, equation[i].token.constant);
-			}
-			if (string) {
-				strcat(string, buf);
+				snprintf(buf, sizeof(buf), "%.*g", precision, equation[i].token.constant);
 			}
+			APPEND(buf);
 			break;
 		case VARIABLE:
-			len += list_var(equation[i].token.variable, 0 - export_flag);
-			if (string)
-				strcat(string, var_str);
+			list_var(equation[i].token.variable, 0 - export_flag);
+			APPEND(var_str);
 			break;
 		case OPERATOR:
 			cp = _("(unknown operator)");
@@ -536,16 +522,12 @@ int		export_flag;
 				i++;
 				break;
 			}
-			len += strlen(cp);
-			if (string)
-				strcat(string, cp);
+			APPEND(cp);
 			break;
 		}
 	}
 	for (j = cur_level - min1; j > 0; j--) {
-		if (string)
-			strcat(string, ")");
-		len++;
+		APPEND(")");
 	}
 	return len;
 }
@@ -948,7 +930,11 @@ check_again:
 			if (oflag) {
 				set_color(level-1);
 				for (j = 0; j < len_div; j++) {
-					fprintf(gfp, "-");
+					if (html_flag) {
+						fprintf(gfp, "&mdash;");
+					} else {
+						fprintf(gfp, "-");
+					}
 				}
 				set_color(cur_level-1);
 			}
