@@ -84,7 +84,7 @@ char	**argv;
 	gfp = stdout;
 
 	/* process command line options */
-	while ((i = getopt(argc, argv, "qtchuvm:")) >= 0) {
+	while ((i = getopt(argc, argv, "qrtchuvm:")) >= 0) {
 		switch (i) {
 		case 'c':
 			coption = true;
@@ -94,15 +94,19 @@ char	**argv;
 			html_flag = true;
 			break;
 		case 'm':
-			multiplier = atof(optarg);
-			if (multiplier <= 0.0 || (n_tokens = (int) (multiplier * DEFAULT_N_TOKENS)) < 100) {
+			multiplier = strtod(optarg, &cp) * DEFAULT_N_TOKENS;
+			if (*cp || multiplier < 100 || multiplier >= (INT_MAX / 3)) {
 				fprintf(stderr, _("Invalid memory size multiplier specified.\n"));
-				usage();
+				exit(1);
 			}
+			n_tokens = (int) multiplier;
 			break;
 		case 'q':
 			quiet_mode = true;
 			break;
+		case 'r':
+			readline_enabled = false;
+			break;
 		case 't':
 			readline_enabled = false;
 			test_mode = true;
@@ -169,7 +173,7 @@ char	**argv;
 			printf(_("Operation abruptly aborted.\n"));
 			break;
 		case 14:
-			error(_("Expression too big."));
+			error(_("Expression too large."));
 		default:
 			printf(_("Operation aborted.\n"));
 		}
@@ -211,9 +215,10 @@ usage()
 	fprintf(stderr, _("Usage: %s [ options ] [ input_files ]\n\n"), prog_name);
 	fprintf(stderr, _("Options:\n"));
 	fprintf(stderr, _("  -c               Toggle color mode.\n"));
-	fprintf(stderr, _("  -h               Enable HTML mode and disable readline input.\n"));
+	fprintf(stderr, _("  -h               Enable HTML mode and disable readline.\n"));
 	fprintf(stderr, _("  -m number        Specify a memory size multiplier.\n"));
 	fprintf(stderr, _("  -q               Quiet mode (don't display prompts).\n"));
+	fprintf(stderr, _("  -r               Disable readline.\n"));
 	fprintf(stderr, _("  -t               Used when testing.\n"));
 	fprintf(stderr, _("  -u               Unbuffered output.\n"));
 	fprintf(stderr, _("  -v               Display version number and compile flags used.\n"));
