@@ -58,8 +58,8 @@
 
 /* memory usage in bytes; can be set to any size; the larger, the faster */
 #define BUFFER_SIZE	2000000
-#if	BUFFER_SIZE >= (INT_MAX / 2)
-#error	BUFFER_SIZE too big!
+#if	BUFFER_SIZE >= (INT_MAX / 2) || BUFFER_SIZE <= 0
+#error	"BUFFER_SIZE too large."
 #endif
 
 void	generate_primes(void);
