@@ -87,6 +87,8 @@ int		*np;
 	simp_side(equation, np);
 	ufactor(equation, np);
 	factorv(equation, np, IMAGINARY);
+	ufactor(equation, np);
+	factorv(equation, np, IMAGINARY);
 	simp_side(equation, np);
 	uf_simp(equation, np);
 	approximate_roots = false;
@@ -408,7 +410,7 @@ int		*np;		/* pointer to length of equation side */
 	int	i;
 	int	rv = false;
 
-	if (*np == 0)
+	if (*np <= 1)	/* no need to simplify a constant or a variable */
 		return rv;
 	do {
 		do {
@@ -996,8 +998,8 @@ double	k2;	/* operand 2 */
 		break;
 	case FACTORIAL:
 #if	true	/* set this to false if lgamma() doesn't exist */
-		d = exp(lgamma(*k1p + 1.0));
-		if (errno) {	/* simply don't evaluate if error */
+		d = exp(lgamma(*k1p + 1.0)) * signgam;
+		if (errno) {	/* don't evaluate if overflow */
 			return false;
 		}
 #else
@@ -1447,6 +1449,7 @@ int		n2, l2, *diff_signp;
 	int		last_op1, op1, op2;
 	int		diff_op;
 	double		d1, c1, c2;
+	double		compare_epsilon = epsilon;
 
 	*diff_signp = false;
 	if (n1 == 1 && n2 == 1) {
@@ -1470,7 +1473,7 @@ int		n2, l2, *diff_signp;
 				*diff_signp = true;
 				return true;
 			}
-			d1 = fabs(c1) * epsilon;
+			d1 = fabs(c1) * compare_epsilon;
 			if (fabs(c1 - c2) < d1) {
 				return true;
 			}
@@ -1526,7 +1529,7 @@ int		n2, l2, *diff_signp;
 	}
 	if (diff_op) {
 		if (p1->kind == CONSTANT && p1->level == l1 && op1 == TIMES) {
-			if (fabs(fabs(p1->token.constant) - 1.0) <= epsilon) {
+			if (fabs(fabs(p1->token.constant) - 1.0) <= compare_epsilon) {
 				if (!compare_recurse(p1 + 2, n1 - 2, min_level(p1 + 2, n1 - 2), p2, n2, l2, diff_signp)) {
 					return false;
 				}
@@ -1537,7 +1540,7 @@ int		n2, l2, *diff_signp;
 			}
 		}
 		if (p2->kind == CONSTANT && p2->level == l2 && op2 == TIMES) {
-			if (fabs(fabs(p2->token.constant) - 1.0) <= epsilon) {
+			if (fabs(fabs(p2->token.constant) - 1.0) <= compare_epsilon) {
 				if (!compare_recurse(p1, n1, l1, p2 + 2, n2 - 2, min_level(p2 + 2, n2 - 2), diff_signp)) {
 					return false;
 				}
@@ -1571,13 +1574,11 @@ no_op2:
 				break;
 		for (i = 0;; i++) {
 			if (i >= oc2) {
-				if ((op1 == TIMES || op1 == DIVIDE)
-				    && pv1->level == l1 && pv1->kind == CONSTANT) {
-					if (fabs(pv1->token.constant + 1.0) <= epsilon) {
-						*diff_signp ^= true;
-						break;
-					}
-					if (fabs(pv1->token.constant - 1.0) <= epsilon) {
+				if ((op1 == TIMES || op1 == DIVIDE) && pv1->level == l1 && pv1->kind == CONSTANT) {
+					if (fabs(fabs(pv1->token.constant) - 1.0) <= compare_epsilon) {
+						if (pv1->token.constant < 0.0) {
+							*diff_signp ^= true;
+						}
 						break;
 					}
 				}
@@ -1641,13 +1642,11 @@ no_op2:
 	}
 	for (i = 0; i < oc2; i++) {
 		if (!used[i]) {
-			if ((op2 == TIMES || op2 == DIVIDE)
-			    && opa2[i]->level == l2 && opa2[i]->kind == CONSTANT) {
-				if (fabs(opa2[i]->token.constant + 1.0) <= epsilon) {
-					*diff_signp ^= true;
-					continue;
-				}
-				if (fabs(opa2[i]->token.constant - 1.0) <= epsilon) {
+			if ((op2 == TIMES || op2 == DIVIDE) && opa2[i]->level == l2 && opa2[i]->kind == CONSTANT) {
+				if (fabs(fabs(opa2[i]->token.constant) - 1.0) <= compare_epsilon) {
+					if (opa2[i]->token.constant < 0.0) {
+						*diff_signp ^= true;
+					}
 					continue;
 				}
 			}
