@@ -1138,7 +1138,7 @@ int		*side2np;	/* pointer to the length of "side2p" */
 		p2++;
 		p2->level = 2;
 		p2->kind = VARIABLE;
-		p2->token.variable = V_INTEGER;
+		parse_var(&p2->token.variable, "integer");
 		p2++;
 		p2->level = 2;
 		p2->kind = OPERATOR;
