@@ -339,7 +339,7 @@ do_gcd:
 /*
  * This function is the guts of the "flist" command.
  */
-group_sub(n)
+make_fractions_and_group(n)
 int	n;
 {
 	if (n_lhs[n] <= 0)
@@ -356,7 +356,7 @@ int	n;
 }
 
 /*
- * Group denominators.
+ * Group denominators together.
  * Grouping here means converting "a/b/c" to "a/(b*c)".
  */
 group_proc(equation, np)
